// Copyright (C) 2008-2009 - INRIA - Michael Baudin
// Copyright (C) 2009-2011 - DIGITEO - Michael Baudin

//
// This file must be used under the terms of the GNU LGPL license.
// 

// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->

//
// Test the "hidden" Fast Faure API in dimension 3
//
dim = 3;
computed = [];
start = _lowdisc_faurefisstart ( );
assert_checkequal ( start , 0 );
// Skip first term
_lowdisc_faurefstart ( dim );
dim2 = _lowdisc_faurefdimget ( );
assert_checkequal ( dim2 , dim );
start = _lowdisc_faurefisstart ( );
assert_checkequal ( start , 1 );
qs = _lowdisc_faurefbaseget ( );
assert_checkequal ( qs , 3 );
imax = 1;
leap = 0;
next = _lowdisc_faurefnext ( 0 , imax , leap );
for i = 1 : 8
  next = _lowdisc_faurefnext ( i , imax , leap );
  computed(i,1:dim) = next;
end
expected= [
    1/3 1/3 1/3
    2/3 2/3 2/3 
    1/9 4/9 7/9 
    4/9 7/9 1/9 
    7/9 1/9 4/9 
    2/9 8/9 5/9 
    5/9 2/9 8/9 
    8/9 5/9 2/9
];
assert_checkalmostequal ( computed, expected, %eps );
_lowdisc_faurefstop ( );
start = _lowdisc_faurefisstart ( );
assert_checkequal ( start , 0 );

//
// Test the "hidden" Fast Faure API in dimension 4
//
dim = 4;
computed = [];
_lowdisc_faurefstart ( dim );
qs = _lowdisc_faurefbaseget ( );
assert_checkequal ( qs , 5 );
imax = 1;
leap = 0;
// Skip first term
next = _lowdisc_faurefnext ( 0 , imax , leap );
for i = 1 : 8
  next = _lowdisc_faurefnext ( i , imax , leap );
  computed(i,1:dim) = next;
end
expected= [
    0.2                    0.2                    0.2                    0.2                  
    0.4                    0.4                    0.4                    0.4                  
    0.6                    0.6                    0.6                    0.6
    0.8                    0.8                    0.8                    0.8                  
    0.04                   0.24                   0.44                   0.64 
    0.24                   0.44                   0.64                   0.84
    0.44                   0.64                   0.84                   0.04                 
    0.64                   0.84                   0.04                   0.24
];
assert_checkalmostequal ( computed, expected, %eps );
_lowdisc_faurefstop ( );


//
// Test the "hidden" API.
// Get elements 0,1,2,3 then 5,6,7, then 1,2,3
// i.e. pick arbitrary experiments in the sequence.
//
dim = 4;
_lowdisc_faurefstart ( dim );
scenario = [0 1 2 3 5 6 7 1 2 3];
computed = [];
imax = 1;
leap = 0;
for k = 1 : size(scenario,"*")
  seed = scenario(k);
  computed(k,1:dim) = _lowdisc_faurefnext ( seed , imax , leap );
end
expected= [
    0.                     0.                     0.                     0.      
    0.2                    0.2                    0.2                    0.2                  
    0.4                    0.4                    0.4                    0.4                  
    0.6                    0.6                    0.6                    0.6
    0.04                   0.24                   0.44                   0.64 
    0.24                   0.44                   0.64                   0.84
    0.44                   0.64                   0.84                   0.04                 
    0.2                    0.2                    0.2                    0.2                  
    0.4                    0.4                    0.4                    0.4                  
    0.6                    0.6                    0.6                    0.6
];
assert_checkalmostequal ( computed , expected , %eps );
_lowdisc_faurefstop ( );

//
// Test the "hidden" Fast Faure API in dimension 2000
//
dim = 2000;
primelist = number_primes10000();
k = find(primelist>dim,1);
qs = primelist(k);
_lowdisc_faurefstart ( dim , qs );
qs2 = _lowdisc_faurefbaseget ( );
assert_checkequal ( qs , qs2 );
imax = 1;
leap = 0;
next = _lowdisc_faurefnext ( 0 , imax , leap );
assert_checkequal ( size(next) , [1 dim] );
_lowdisc_faurefstop ( );


//
// Test the "hidden" Fast Faure API in dimension 4.
// Produce several elements in one single call.
//
dim = 4;
computed = [];
_lowdisc_faurefstart ( dim );
qs = _lowdisc_faurefbaseget ( );
assert_checkequal ( qs , 5 );
leap = 0;
// Skip first term
next = _lowdisc_faurefnext ( 0 , 1 , leap );
computed = _lowdisc_faurefnext ( 1 , 8 , leap );
expected= [
    0.2                    0.2                    0.2                    0.2                  
    0.4                    0.4                    0.4                    0.4                  
    0.6                    0.6                    0.6                    0.6
    0.8                    0.8                    0.8                    0.8                  
    0.04                   0.24                   0.44                   0.64 
    0.24                   0.44                   0.64                   0.84
    0.44                   0.64                   0.84                   0.04                 
    0.64                   0.84                   0.04                   0.24
];
assert_checkalmostequal ( computed, expected, %eps );
_lowdisc_faurefstop ( );
